@@ -88,7 +88,7 @@ class App:
         """
         Create dockerfile
         """
-        root = pathlib.Path(__file__).parent.parent.parent.parent
+        root = pathlib.Path(__file__).parent.parent
         template = root.joinpath("template", "Dockerfile")
         dockerfile = self.config.joinpath("Dockerfile")
         logger.debug(f"Copying Docker template")
@@ -146,7 +146,7 @@ class App:
             output = output.decode("utf-8")
             output = output.strip()
             output = codecs.decode(output, "unicode_escape")
-            match = re.search(":\"(.*)\S?", output, re.M)
+            match = re.search(r":\"(.*)\S?", output, re.M)
             if match:
                 yield match.group(1)
             else:
